@@ -24,14 +24,24 @@ from sentry.processors.base import send_group_processors
 from sentry.signals import regression_signal
 from sentry.utils import get_db_engine
 from sentry.utils.charts import has_charts
-from sentry.utils.compat.db import connections
-from sentry.utils.dates import utc_to_local
+from sentry.utils.dates import utc_to_local, get_sql_date_trunc
 from sentry.queue.client import delay
 from sentry.queue.tasks.index import index_event
 
 logger = logging.getLogger('sentry.errors')
 
 
+def get_checksum_from_event(event):
+    for interface in event.interfaces.itervalues():
+        result = interface.get_hash()
+        if result:
+            hash = hashlib.md5()
+            for r in result:
+                hash.update(r)
+            return hash.hexdigest()
+    return hashlib.md5(event.message).hexdigest()
+
+
 class ScoreClause(object):
     def __init__(self, group):
         self.group = group
@@ -83,18 +93,6 @@ class ModuleProxyCache(dict):
 
 
 class ChartMixin(object):
-    def _get_date_trunc(self, col, db='default'):
-        conn = connections[db]
-
-        engine = get_db_engine(db)
-        # TODO: does extract work for sqlite?
-        if engine.startswith('oracle'):
-            method = conn.ops.date_trunc_sql('hh24', col)
-        else:
-            method = conn.ops.date_trunc_sql('hour', col)
-
-        return method
-
     def get_chart_data(self, instance, max_days=90):
         if hasattr(instance, '_state'):
             db = instance._state.db
@@ -105,10 +103,10 @@ class ChartMixin(object):
             return []
 
         hours = max_days * 24
-        today = datetime.datetime.utcnow().replace(microsecond=0, second=0, minute=0)
+        today = datetime.datetime.now().replace(microsecond=0, second=0, minute=0)
         min_date = today - datetime.timedelta(hours=hours)
 
-        method = self._get_date_trunc('date', db)
+        method = get_sql_date_trunc('date', db)
 
         chart_qs = list(instance.messagecountbyminute_set\
                           .filter(date__gte=min_date)\
@@ -212,7 +210,7 @@ class GroupManager(models.Manager, ChartMixin):
         # TODO: this function is way too damn long and needs refactored
         # the inner imports also suck so let's try to move it away from
         # the objects manager
-        from sentry.models import Event, Project, View, SearchDocument
+        from sentry.models import Event, Project, View
         from sentry.views import View as ViewHandler
 
         project = Project.objects.get(pk=project)
@@ -242,8 +240,6 @@ class GroupManager(models.Manager, ChartMixin):
             raise InvalidData('Missing required parameter: message')
 
         checksum = kwargs.pop('checksum', None)
-        if not checksum:
-            checksum = hashlib.md5(message).hexdigest()
 
         data = kwargs
 
@@ -286,6 +282,10 @@ class GroupManager(models.Manager, ChartMixin):
             **kwargs
         )
 
+        # Calculcate the checksum from the first highest scoring interface
+        if not checksum:
+            checksum = get_checksum_from_event(event)
+
         group_kwargs = kwargs.copy()
         group_kwargs.update({
             'last_seen': date,
@@ -432,6 +432,17 @@ class GroupManager(models.Manager, ChartMixin):
                 time_spent_count=time_spent and 1 or 0,
             )
 
+        affected = project.projectcountbyminute_set.filter(
+            date=normalized_datetime,
+        ).update(**update_kwargs)
+        if not affected:
+            project.projectcountbyminute_set.create(
+                date=normalized_datetime,
+                times_seen=1,
+                time_spent_total=time_spent or 0,
+                time_spent_count=time_spent and 1 or 0,
+            )
+
         http = event.interfaces.get('sentry.interfaces.Http')
         if http:
             url = http.url
