@@ -7,9 +7,10 @@ sentry.plugins.sentry_servers
 """
 
 from django.db.models import Sum
-from sentry.plugins import Plugin
+from sentry.plugins import Plugin, register
 
 
+@register
 class ServersPlugin(Plugin):
     """
     Adds additional support for showing information about servers including:
